@@ -1173,7 +1173,7 @@ const char *dont_mount_in_root[] = {
 };
 
 /* We don't want to export paths pointing into these, because they are readonly
-   (so we can't create mountpoints there) and don't match whats on the host anyway */
+   (so we can't create mountpoints there) and don't match what's on the host anyway */
 const char *dont_export_in[] = {
   "/lib", "/lib32", "/lib64", "/bin", "/sbin", "/usr", "/etc", "/app", NULL
 };
